@@ -14,7 +14,7 @@ def flush(filename) -> None:
 
 def output(self,anything,end="\n") -> None:
     #wx.CallAfter(outPutToOutPut,self,str(anything)+end)
-    self.output.AppendText(self, str(anything) + end)
+    self.output.AppendText(str(anything) + end)
 
 def outPutToOutPut(self,msg:str) -> None:
     self.output.AppendText(msg)
